summaryrefslogtreecommitdiffstats
path: root/sys/scsi/st.c
diff options
context:
space:
mode:
authorjoerg <joerg@FreeBSD.org>1996-06-22 14:57:55 +0000
committerjoerg <joerg@FreeBSD.org>1996-06-22 14:57:55 +0000
commit33d0c3d6f4f40693bdf0df6da2f2a12b87c0e5bc (patch)
tree5ee0b084782ecfd24761318ad240be656fd7c9a8 /sys/scsi/st.c
parentf922895864188c2cf56283cde36655ca8200dbfe (diff)
downloadFreeBSD-src-33d0c3d6f4f40693bdf0df6da2f2a12b87c0e5bc.zip
FreeBSD-src-33d0c3d6f4f40693bdf0df6da2f2a12b87c0e5bc.tar.gz
Dump the timeout for st_erase().
Fixes PR # kern/1341: Bug fix for SCSI tape Submitted by: tundra@tundrware.com
Diffstat (limited to 'sys/scsi/st.c')
-rw-r--r--sys/scsi/st.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/scsi/st.c b/sys/scsi/st.c
index 1514a94..3998e17 100644
--- a/sys/scsi/st.c
+++ b/sys/scsi/st.c
@@ -12,7 +12,7 @@
* on the understanding that TFS is not responsible for the correct
* functioning of this software in any circumstances.
*
- * $Id: st.c,v 1.67 1996/04/01 02:12:53 scrappy Exp $
+ * $Id: st.c,v 1.68 1996/04/02 04:54:26 scrappy Exp $
*/
/*
@@ -1780,7 +1780,7 @@ st_erase(unit, immed, flags)
0,
0,
ST_RETRIES,
- immed ? 5000 : 300000, /* 5 sec or 5 min */
+ immed ? 5000 : (200 * 60 * 1000), /* 5 sec or 200 min */
NULL,
flags));
}
OpenPOWER on IntegriCloud